@@ -13,17 +13,8 @@ import click
     type=bool,
     help="Force write the target file",
 )
-@click.argument(
-    "target",
-    required=True,
-    type=str,
-)
-@click.argument(
-    "source",
-    required=True,
-    type=str,
-    nargs=-1,
-)
+@click.argument("target", required=True, type=str)
+@click.argument("source", required=True, type=str, nargs=-1)
 def cli(force, target, source):
     """
     stacker for npz files.
